@@ -1,7 +1,6 @@
-use std::result;
+use std::{io, result};
 use quick_xml::Reader;
 use quick_xml::events::{Event};
-use tempdir::TempDir;
 use super::XlsxError;
 use super::driver::*;
 use std::collections::HashMap;
@@ -10,12 +9,13 @@ use structs::Color;
 use structs::Anchor;
 use helper::coordinate::*;
 
-pub(crate) fn read(
-    dir: &TempDir,
+pub(crate) fn read<R: io::Read + io::Seek>(
+    arv: &mut zip::read::ZipArchive<R>,
     target: &str,
 ) -> result::Result<HashMap<String, Comment>, XlsxError> {
-    let path = dir.path().join(format!("xl/drawings/{}", target));
-    let mut reader = Reader::from_file(path)?;
+    let path_str = normalize_path_to_str(&format!("xl/drawings/{}", target));
+    let r = io::BufReader::new(arv.by_name(path_str.as_str())?);
+    let mut reader = Reader::from_reader(r);
     reader.trim_text(true);
     let mut buf = Vec::new();
 
