@@ -1,6 +1,7 @@
+use std::io::Read;
 use quick_xml::Reader;
 use quick_xml::events::{Event};
-use tempdir::TempDir;
+use std::io;
 use super::XlsxError;
 use super::driver::*;
 
@@ -15,17 +16,23 @@ use ::structs::PageMargins;
 use ::structs::Hyperlink;
 use ::structs::ConditionalSet;
 use ::structs::Columns;
+use ::structs::OleObjects;
 
-pub(crate) fn read(
-    dir: &TempDir,
+pub(crate) fn read<R: io::Read + io::Seek>(
+    arv: &mut zip::read::ZipArchive<R>,
     target: &String,
     spreadsheet: &mut Spreadsheet,
     sheets_sheet_id: &str,
     sheets_name: &str,
 ) -> Result<(Option<String>, Option<String>, Vec<(String, String)>), XlsxError> {
-    
-    let path = dir.path().join(format!("xl/{}", target));
-    let mut reader = Reader::from_file(path)?;
+    let data = {
+        let path_str = normalize_path_to_str(&format!("xl/{}", target));
+        let mut r = io::BufReader::new(arv.by_name(path_str.as_str())?);
+        let mut buf = Vec::new();
+        r.read_to_end(&mut buf)?;
+        std::io::Cursor::new(buf)
+    };
+    let mut reader = Reader::from_reader(data);
     reader.trim_text(true);
     let mut buf = Vec::new();
 
@@ -89,6 +96,11 @@ pub(crate) fn read(
                         conditional_set.set_conditional_collection(conditional_styles_collection);
                         worksheet.add_conditional_styles_collection(conditional_set);
                     },
+                    b"oleObjects" => {
+                        //let mut obj = OleObjects::default();
+                        //obj.set_attributes(&mut reader, e, arv, Some(sheets_name));
+                        //worksheet.set_ole_objects(obj);
+                    },
                     _ => (),
                 }
             },
@@ -173,8 +185,8 @@ pub(crate) fn read(
     Ok((drawing, legacy_drawing, hyperlink_vec))
 }
 
-fn get_conditional_formatting(
-    reader:&mut quick_xml::Reader<std::io::BufReader<std::fs::File>>,
+fn get_conditional_formatting<R: std::io::BufRead>(
+    reader:&mut Reader<R>,
     stylesheet: &Stylesheet,
     theme: &Theme
 ) -> Vec<Conditional>
@@ -265,8 +277,8 @@ fn get_conditional_formatting(
     }
 }
 
-fn get_cfvo(
-    reader:&mut quick_xml::Reader<std::io::BufReader<std::fs::File>>,
+fn get_cfvo<R: std::io::BufRead>(
+    reader:&mut Reader<R>,
     theme: &Theme
 )->Vec<(String, Option<String>, Option<Color>)>
 {
