@@ -22,9 +22,9 @@ impl Camera {
         self
     }
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        _reader:&mut Reader<R>,
         e:&BytesStart
     ) {
         match get_attribute(e, b"prst") {
