@@ -182,9 +182,9 @@ impl Chart {
         self.get_plot_area_mut().get_formula_mut()
     }
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        reader:&mut Reader<R>,
         _e:&BytesStart
     ) {
         let mut buf = Vec::new();
