@@ -28,9 +28,9 @@ impl Layout {
         self.manual_layout.is_none()
     }
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        reader:&mut Reader<R>,
         _e:&BytesStart,
         empty_flag:bool,
     ) {
