@@ -32,9 +32,9 @@ impl NumberingFormat {
         self
     }
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        _reader:&mut Reader<R>,
         e:&BytesStart
     ) {
         &mut self.format_code.set_value_string(get_attribute(e, b"formatCode").unwrap());
