@@ -51,9 +51,9 @@ impl EffectList {
         self.soft_edge = Some(value);
     }
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        reader:&mut Reader<R>,
         _e:&BytesStart,
         empty_flag: bool,
     ) {
