@@ -29,9 +29,9 @@ impl EndConnection {
         self.index.set_value(value);
     }
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        _reader:&mut Reader<R>,
         e:&BytesStart
     ) {
         &mut self.id.set_value_string(get_attribute(e, b"id").unwrap());
