@@ -45,9 +45,9 @@ impl FillRectangle {
         self.top = value;
     }
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        _reader:&mut Reader<R>,
         _e:&BytesStart
     ) {
 
