@@ -5,7 +5,6 @@ use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use quick_xml::Reader;
 use std::io::Cursor;
-use tempdir::TempDir;
 
 #[derive(Default, Debug)]
 pub struct Graphic {
@@ -25,11 +24,11 @@ impl Graphic {
         self
     }
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead, A: std::io::Read + std::io::Seek>(
         &mut self,
-        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        reader:&mut Reader<R>,
         _e:&BytesStart,
-        dir: &TempDir,
+        arv: &mut zip::read::ZipArchive<A>,
         target: &str,
     ) {
         let mut buf = Vec::new();
@@ -39,7 +38,7 @@ impl Graphic {
                 Ok(Event::Start(ref e)) => {
                     match e.name() {
                         b"a:graphicData" => {
-                            &mut self.graphic_data.set_attributes(reader, e, dir, target);
+                            &mut self.graphic_data.set_attributes(reader, e, arv, target);
                         },
                         _ => (),
                     }
