@@ -50,9 +50,9 @@ impl Shape3DType {
         self.bevel_bottom = Some(value);
     }
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        reader:&mut Reader<R>,
         e:&BytesStart
     ) {
         &mut self.preset_material.set_value_string(get_attribute(e, b"prstMaterial").unwrap());
