@@ -10,9 +10,9 @@ pub struct ShapeAutoFit {
 }
 impl ShapeAutoFit {
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        _reader:&mut Reader<R>,
         _:&BytesStart
     ) {
     }
