@@ -11,10 +11,10 @@ pub struct NonVisualGraphicFrameDrawingProperties {
 }
 impl NonVisualGraphicFrameDrawingProperties {
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
-        e:&BytesStart
+        _reader:&mut Reader<R>,
+        _e:&BytesStart
     ) {
 
     }
