@@ -39,10 +39,10 @@ impl NonVisualGraphicFrameProperties {
         self
     }
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
-        e:&BytesStart
+        reader:&mut Reader<R>,
+        _e:&BytesStart
     ) {
         let mut buf = Vec::new();
         loop {
