@@ -69,9 +69,9 @@ impl Transform {
         self.horizontal_flip.set_value(value);
     }
     
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        reader:&mut Reader<R>,
         e:&BytesStart
     ) {
         let mut buf = Vec::new();
