@@ -10,10 +10,10 @@ pub struct TileRectangle {
 
 }
 impl TileRectangle {
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
-        e:&BytesStart
+        _reader:&mut Reader<R>,
+        _e:&BytesStart
     ) {
 
     }
