@@ -73,9 +73,9 @@ impl Transform2D {
         self.flip_h = Some(value.into());
     }
     
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        reader:&mut Reader<R>,
         e:&BytesStart
     ) {
         let mut buf = Vec::new();
