@@ -1,13 +1,13 @@
-use super::Column;
-use super::Row;
+use super::ColumnReference;
+use super::RowReference;
 use ::helper::coordinate::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct Range {
-    coordinate_start_col: Option<Column>,
-    coordinate_start_row: Option<Row>,
-    coordinate_end_col: Option<Column>,
-    coordinate_end_row: Option<Row>,
+    coordinate_start_col: Option<ColumnReference>,
+    coordinate_start_row: Option<RowReference>,
+    coordinate_end_col: Option<ColumnReference>,
+    coordinate_end_row: Option<RowReference>,
 }
 impl Range {
     pub fn set_range<S: Into<String>>(&mut self, value:S)-> &mut Self {
@@ -23,7 +23,7 @@ impl Range {
             let nums = index_from_coordinate(coordinate_str);
             match nums[0] {
                 Some(v)=> {
-                    let mut coordinate_start_col = Column::default();
+                    let mut coordinate_start_col = ColumnReference::default();
                     coordinate_start_col.set_num(v);
                     coordinate_start_col.set_is_lock_usize(nums[2].unwrap());
                     self.coordinate_start_col = Some(coordinate_start_col);
@@ -31,7 +31,7 @@ impl Range {
             };
             match nums[1] {
                 Some(v)=> {
-                    let mut coordinate_start_row = Row::default();
+                    let mut coordinate_start_row = RowReference::default();
                     coordinate_start_row.set_num(v);
                     coordinate_start_row.set_is_lock_usize(nums[3].unwrap());
                     self.coordinate_start_row = Some(coordinate_start_row);
@@ -44,7 +44,7 @@ impl Range {
             let nums = index_from_coordinate(coordinate_str);
             match nums[0] {
                 Some(v)=> {
-                    let mut coordinate_end_col = Column::default();
+                    let mut coordinate_end_col = ColumnReference::default();
                     coordinate_end_col.set_num(v);
                     coordinate_end_col.set_is_lock_usize(nums[2].unwrap());
                     self.coordinate_end_col = Some(coordinate_end_col);
@@ -52,7 +52,7 @@ impl Range {
             };
             match nums[1] {
                 Some(v)=> {
-                    let mut coordinate_end_row = Row::default();
+                    let mut coordinate_end_row = RowReference::default();
                     coordinate_end_row.set_num(v);
                     coordinate_end_row.set_is_lock_usize(nums[3].unwrap());
                     self.coordinate_end_row = Some(coordinate_end_row);
@@ -70,35 +70,35 @@ impl Range {
         result
     }
 
-    pub fn get_coordinate_start_col(&self)-> &Option<Column> {
+    pub fn get_coordinate_start_col(&self)-> &Option<ColumnReference> {
         &self.coordinate_start_col
     }
 
-    pub fn get_coordinate_start_col_mut(&mut self)-> &mut Option<Column> {
+    pub fn get_coordinate_start_col_mut(&mut self)-> &mut Option<ColumnReference> {
         &mut self.coordinate_start_col
     }
 
-    pub fn get_coordinate_start_row(&self)-> &Option<Row> {
+    pub fn get_coordinate_start_row(&self)-> &Option<RowReference> {
         &self.coordinate_start_row
     }
 
-    pub fn get_coordinate_start_row_mut(&mut self)-> &mut Option<Row> {
+    pub fn get_coordinate_start_row_mut(&mut self)-> &mut Option<RowReference> {
         &mut self.coordinate_start_row
     }
 
-    pub fn get_coordinate_end_col(&self)-> &Option<Column> {
+    pub fn get_coordinate_end_col(&self)-> &Option<ColumnReference> {
         &self.coordinate_end_col
     }
 
-    pub fn get_coordinate_end_col_mut(&mut self)-> &mut Option<Column> {
+    pub fn get_coordinate_end_col_mut(&mut self)-> &mut Option<ColumnReference> {
         &mut self.coordinate_end_col
     }
 
-    pub fn get_coordinate_end_row(&self)-> &Option<Row> {
+    pub fn get_coordinate_end_row(&self)-> &Option<RowReference> {
         &self.coordinate_end_row
     }
 
-    pub fn get_coordinate_end_row_mut(&mut self)-> &mut Option<Row> {
+    pub fn get_coordinate_end_row_mut(&mut self)-> &mut Option<RowReference> {
         &mut self.coordinate_end_row
     }
 
@@ -128,7 +128,7 @@ impl Range {
         coordinate_str
     }
 
-    pub(crate) fn adjustment_insert_coordinate(&mut self, root_col_num:&usize, offset_col_num:&usize, root_row_num:&usize, offset_row_num:&usize) {
+    pub(crate) fn adjustment_insert_coordinate(&mut self, root_col_num:&u32, offset_col_num:&u32, root_row_num:&u32, offset_row_num:&u32) {
         match &mut self.coordinate_start_col {
             Some(v) => {v.adjustment_insert_coordinate(root_col_num, offset_col_num);},
             None => {},
@@ -147,7 +147,7 @@ impl Range {
         }
     }
 
-    pub(crate) fn adjustment_remove_coordinate(&mut self, root_col_num:&usize, offset_col_num:&usize, root_row_num:&usize, offset_row_num:&usize) {
+    pub(crate) fn adjustment_remove_coordinate(&mut self, root_col_num:&u32, offset_col_num:&u32, root_row_num:&u32, offset_row_num:&u32) {
         match &mut self.coordinate_start_col {
             Some(v) => {v.adjustment_remove_coordinate(root_col_num, offset_col_num);},
             None => {},
@@ -166,7 +166,7 @@ impl Range {
         }
     }
 
-    pub(crate) fn is_remove(&self, root_col_num:&usize, offset_col_num:&usize, root_row_num:&usize, offset_row_num:&usize)->bool {
+    pub(crate) fn is_remove(&self, root_col_num:&u32, offset_col_num:&u32, root_row_num:&u32, offset_row_num:&u32)->bool {
         let start_col_result = match &self.coordinate_start_col {Some(v)=> v.is_remove(root_col_num, offset_col_num), None=>false};
         let start_row_result = match &self.coordinate_start_row {Some(v)=> v.is_remove(root_row_num, offset_row_num), None=>false};
         let end_col_result = match &self.coordinate_end_col {Some(v)=> v.is_remove(root_col_num, offset_col_num), None=>false};
