@@ -1,35 +1,35 @@
 use super::TextElement;
-use writer::driver::*;
+use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
-use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
-pub struct RichText  {
+pub struct RichText {
     rich_text_elements: Vec<TextElement>,
     text: String,
 }
-impl RichText  {
+impl RichText {
     pub fn get_text(&self) -> &str {
         &self.text
     }
 
-    pub fn get_rich_text_elements(&self)-> &Vec<TextElement> {
+    pub fn get_rich_text_elements(&self) -> &Vec<TextElement> {
         &self.rich_text_elements
     }
 
-    pub fn get_rich_text_elements_mut(&mut self)-> &mut Vec<TextElement> {
+    pub fn get_rich_text_elements_mut(&mut self) -> &mut Vec<TextElement> {
         &mut self.rich_text_elements
     }
 
-    pub fn set_rich_text_elements(&mut self, value:Vec<TextElement>) ->&mut Self {
+    pub fn set_rich_text_elements(&mut self, value: Vec<TextElement>) -> &mut Self {
         self.rich_text_elements = value;
         self.refresh_text();
         self
     }
 
-    pub fn add_rich_text_elements(&mut self, value:TextElement) ->&mut Self {
+    pub fn add_rich_text_elements(&mut self, value: TextElement) -> &mut Self {
         self.rich_text_elements.push(value);
         self.refresh_text();
         self
@@ -43,39 +43,29 @@ impl RichText  {
         self.text = text;
     }
 
-    pub(crate) fn get_hash_code(&self)-> String {
+    pub(crate) fn get_hash_code(&self) -> String {
         let mut value = String::from("");
         for ele in &self.rich_text_elements {
             value += ele.get_hash_code().as_str();
         }
-        format!("{:x}", md5::compute(format!("{}",
-            value
-        )))
+        format!("{:x}", md5::compute(format!("{}", value)))
     }
 
-    pub(crate) fn set_attributes_text(
-        &mut self,
-        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
-        _e:&BytesStart
-    ) {
+    pub(crate) fn set_attributes_text<R: std::io::BufRead>(&mut self, reader: &mut Reader<R>, _e: &BytesStart) {
         let mut buf = Vec::new();
         loop {
             match reader.read_event(&mut buf) {
-                Ok(Event::Start(ref e)) => {
-                    match e.name() {
-                        b"r" => {
-                            let mut obj = TextElement::default();
-                            obj.set_attributes(reader, e);
-                            self.add_rich_text_elements(obj);
-                        },
-                        _ => (),
+                Ok(Event::Start(ref e)) => match e.name() {
+                    b"r" => {
+                        let mut obj = TextElement::default();
+                        obj.set_attributes(reader, e);
+                        self.add_rich_text_elements(obj);
                     }
+                    _ => (),
                 },
-                Ok(Event::End(ref e)) => {
-                    match e.name() {
-                        b"text" => return,
-                        _ => (),
-                    }
+                Ok(Event::End(ref e)) => match e.name() {
+                    b"text" => return,
+                    _ => (),
                 },
                 Ok(Event::Eof) => panic!("Error not find {} end element", "text"),
                 Err(e) => panic!("Error at position {}: {:?}", reader.buffer_position(), e),
@@ -89,7 +79,7 @@ impl RichText  {
         // none
         self.write_to(writer, "");
     }
-    
+
     pub(crate) fn write_to_text(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
         // text
         self.write_to(writer, "text");
