@@ -113,9 +113,9 @@ impl Row {
         }
     }
 
-    pub(crate) fn set_attributes(
+    pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<std::io::BufReader<std::fs::File>>,
+        reader:&mut Reader<R>,
         e:&BytesStart,
         worksheet: &mut Worksheet,
         shared_string_table: &SharedStringTable,
