@@ -7,6 +7,7 @@ use super::DefinedName;
 use super::Theme;
 use super::Stylesheet;
 use super::SharedStringTable;
+use super::WorkbookView;
 use helper::coordinate::*;
 
 #[derive(Default, Debug)]
@@ -15,7 +16,6 @@ pub struct Spreadsheet {
     security: Security,
     work_sheet_collection: Vec<Worksheet>,
     calculation_engine: Calculation,
-    active_sheet_index: usize,
     named_ranges: Vec<String>,
     has_macros: bool,
     macros_code: Option<Vec<u8>>,
@@ -35,6 +35,7 @@ pub struct Spreadsheet {
     defined_names: Vec<DefinedName>,
     stylesheet: Stylesheet,
     shared_string_table: SharedStringTable,
+    workbook_view: WorkbookView,
 }
 impl Spreadsheet {
     // ************************
@@ -51,7 +52,7 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// book.insert_new_row("Sheet1", 2, 3);
     /// ```
-    pub fn insert_new_row<S: Into<String>>(&mut self, sheet_name:S, row_index:usize, num_rows:usize) {
+    pub fn insert_new_row<S: Into<String>>(&mut self, sheet_name:S, row_index:u32, num_rows:u32) {
         self.adjustment_insert_coordinate(&sheet_name.into(), &0, &0, &row_index, &num_rows);
     }
 
@@ -65,7 +66,7 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// book.insert_new_colmun("Sheet1", "B", 3);
     /// ```
-    pub fn insert_new_colmun<S: Into<String>>(&mut self, sheet_name:S, column:S, num_columns:usize) {
+    pub fn insert_new_colmun<S: Into<String>>(&mut self, sheet_name:S, column:S, num_columns:u32) {
         let column_upper = column.into().to_uppercase();
         let column_index = column_index_from_string(column_upper);
         self.insert_new_colmun_by_index(&sheet_name.into(), column_index, num_columns);
@@ -81,7 +82,7 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// book.insert_new_colmun_by_index("Sheet1", 2, 3);
     /// ```
-    pub fn insert_new_colmun_by_index<S: Into<String>>(&mut self, sheet_name:S, column_index:usize, num_columns:usize) {
+    pub fn insert_new_colmun_by_index<S: Into<String>>(&mut self, sheet_name:S, column_index:u32, num_columns:u32) {
         self.adjustment_insert_coordinate(&sheet_name.into(), &column_index, &num_columns, &0, &0);
     }
 
@@ -95,7 +96,7 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// book.remove_row("Sheet1", 2, 3);
     /// ```
-    pub fn remove_row<S: Into<String>>(&mut self, sheet_name:S, row_index:usize, num_rows:usize) {
+    pub fn remove_row<S: Into<String>>(&mut self, sheet_name:S, row_index:u32, num_rows:u32) {
         self.adjustment_remove_coordinate(&sheet_name.into(), &0, &0, &row_index, &num_rows);
     }
 
@@ -109,7 +110,7 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// book.remove_colmun("Sheet1", "B", 3);
     /// ```
-    pub fn remove_colmun<S: Into<String>>(&mut self, sheet_name:S, column:S, num_columns:usize) {
+    pub fn remove_colmun<S: Into<String>>(&mut self, sheet_name:S, column:S, num_columns:u32) {
         let column_upper = column.into().to_uppercase();
         let column_index = column_index_from_string(column_upper);
         self.remove_colmun_by_index(&sheet_name.into(), column_index, num_columns);
@@ -125,11 +126,11 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// book.remove_colmun_by_index("Sheet1", 2, 3);
     /// ```
-    pub fn remove_colmun_by_index<S: Into<String>>(&mut self, sheet_name:S, column_index:usize, num_columns:usize) {
+    pub fn remove_colmun_by_index<S: Into<String>>(&mut self, sheet_name:S, column_index:u32, num_columns:u32) {
         self.adjustment_remove_coordinate(&sheet_name.into(), &column_index, &num_columns, &0, &0);
     }
 
-    pub(crate) fn adjustment_insert_coordinate(&mut self, sheet_name:&str, column_index:&usize, num_columns:&usize, row_index:&usize, num_rows:&usize) {
+    pub(crate) fn adjustment_insert_coordinate(&mut self, sheet_name:&str, column_index:&u32, num_columns:&u32, row_index:&u32, num_rows:&u32) {
         for defined_name in &mut self.defined_names {
             defined_name.get_address_obj_mut().adjustment_insert_coordinate(sheet_name, column_index, num_columns, row_index, num_rows);
         }
@@ -138,7 +139,7 @@ impl Spreadsheet {
         }
     }
 
-    pub(crate) fn adjustment_remove_coordinate(&mut self, sheet_name:&str, column_index:&usize, num_columns:&usize, row_index:&usize, num_rows:&usize) {
+    pub(crate) fn adjustment_remove_coordinate(&mut self, sheet_name:&str, column_index:&u32, num_columns:&u32, row_index:&u32, num_rows:&u32) {
         self.defined_names.retain(|x| {
             !(x.get_address_obj().is_remove(sheet_name, column_index, num_columns, row_index, num_rows))
         });
@@ -273,14 +274,6 @@ impl Spreadsheet {
         self.unparsed_loaded_data = value;
     }
 
-    pub fn get_active_sheet_index(&self) -> &usize {
-        &self.active_sheet_index
-    }
-
-    pub(crate) fn set_active_sheet_index(&mut self, value:usize) {
-        self.active_sheet_index = value;
-    }
-
     pub(crate) fn get_stylesheet(&self) -> &Stylesheet {
         &self.stylesheet
     }
@@ -433,4 +426,17 @@ impl Spreadsheet {
         }
         false
     }
+
+    pub fn get_workbook_view(&self) -> &WorkbookView {
+        &self.workbook_view
+    }
+
+    pub fn get_workbook_view_mut(&mut self) -> &mut WorkbookView {
+        &mut self.workbook_view
+    }
+
+    pub fn set_workbook_view(&mut self, value:WorkbookView) -> &mut Self {
+        self.workbook_view = value;
+        self
+    }
 }
