@@ -26,6 +26,7 @@ mod vba_project_bin;
 mod comment;
 mod vml_drawing;
 mod media;
+mod embeddings;
 
 #[derive(Debug)]
 pub enum XlsxError {
@@ -59,7 +60,13 @@ impl From<FromUtf8Error> for XlsxError {
     }
 }
 
-pub(crate) fn write_crate<W: io::Seek + io::Write>(spreadsheet: &Spreadsheet, writer: W) -> Result<(), XlsxError> {
+/// write spreadsheet file to arbitrary writer.
+/// # Arguments
+/// * `spreadsheet` - Spreadsheet structs object.
+/// * `writer` - writer to write to.
+/// # Return value
+/// * `Result` - OK is void. Err is error message. 
+pub fn write_writer<W: io::Seek + io::Write>(spreadsheet: &Spreadsheet, writer: W) -> Result<(), XlsxError> {
     let mut arv = zip::ZipWriter::new(writer);
 
     // Add Content_Types
@@ -116,9 +123,8 @@ pub(crate) fn write_crate<W: io::Seek + io::Write>(spreadsheet: &Spreadsheet, wr
             chart_id += 1;
         }
 
-        for picture in worksheet.get_worksheet_drawing().get_picture_collection(){
-            let _ = media::write(picture, &mut arv, "xl/media");
-        }
+        let _ = media::write(worksheet, &mut arv, "xl/media");
+        let _ = embeddings::write(worksheet, &mut arv, "xl/embeddings");
     }
 
     // Add SharedStrings
@@ -144,5 +150,5 @@ pub(crate) fn write_crate<W: io::Seek + io::Write>(spreadsheet: &Spreadsheet, wr
 /// let _ = umya_spreadsheet::writer::xlsx::write(&book, path);
 /// ```
 pub fn write(spreadsheet: &Spreadsheet, path: &Path) -> Result<(), XlsxError> {
-    write_crate(spreadsheet, &mut io::BufWriter::new(fs::File::create(path)?))
+    write_writer(spreadsheet, &mut io::BufWriter::new(fs::File::create(path)?))
 }
