@@ -1,21 +1,20 @@
 use structs::drawing::charts::ChartSpace;
 use quick_xml::events::{Event, BytesDecl};
 use quick_xml::Writer;
-use std::io::Cursor;
-use tempdir::TempDir;
+use std::io;
 use super::driver::*;
 use super::XlsxError;
 
 const SUB_DIR: &'static str = "xl/charts";
 
-pub(crate) fn write(
+pub(crate) fn write<W: io::Seek + io::Write>(
     chart_space: &ChartSpace,
     p_chart_id: &usize,
-    dir: &TempDir
+    arv: &mut zip::ZipWriter<W>
 ) -> Result<(), XlsxError> {
     let file_name = format!("chart{}.xml", p_chart_id);
 
-    let mut writer = Writer::new(Cursor::new(Vec::new()));
+    let mut writer = Writer::new(io::Cursor::new(Vec::new()));
     // XML header
     let _ = writer.write_event(Event::Decl(BytesDecl::new(b"1.0", Some(b"UTF-8"), Some(b"yes"))));
     write_new_line(&mut writer);
@@ -23,6 +22,6 @@ pub(crate) fn write(
     // c:chartSpace
     chart_space.write_to(&mut writer);
 
-    let _ = make_file_from_writer(format!("{}/{}", SUB_DIR, file_name).as_str(), dir, writer, Some(SUB_DIR)).unwrap();
+    let _ = make_file_from_writer(&file_name, arv, writer, Some(SUB_DIR)).unwrap();
     Ok(())
 }
