@@ -1,14 +1,13 @@
 use quick_xml::events::{Event, BytesDecl};
 use quick_xml::Writer;
-use std::io::Cursor;
-use tempdir::TempDir;
+use std::io;
 
 use ::structs::Spreadsheet;
 use super::driver::*;
 use super::XlsxError;
 
-pub(crate) fn write(spreadsheet: &Spreadsheet, dir: &TempDir, file_name: &str) -> Result<(), XlsxError> {
-    let mut writer = Writer::new(Cursor::new(Vec::new()));
+pub(crate) fn write<W: io::Seek + io::Write>(spreadsheet: &Spreadsheet, arv: &mut zip::ZipWriter<W>, file_name: &str) -> Result<(), XlsxError> {
+    let mut writer = Writer::new(io::Cursor::new(Vec::new()));
     // XML header
     let _ = writer.write_event(Event::Decl(BytesDecl::new(b"1.0", Some(b"UTF-8"), Some(b"yes"))));
     write_new_line(&mut writer);
@@ -201,6 +200,6 @@ pub(crate) fn write(spreadsheet: &Spreadsheet, dir: &TempDir, file_name: &str) -
     ], true);
 
     write_end_tag(&mut writer, "Types");
-    let _ = make_file_from_writer(format!("{}",file_name).as_str(), dir, writer, None).unwrap();
+    let _ = make_file_from_writer(&file_name, arv, writer, None).unwrap();
     Ok(())
 }
\ No newline at end of file
